#ifndef __BASIC_COLOURS_H__
#define __BASIC_COLOURS_H__

enum {
    DIR_COLOR,
    FSTAB_COLOR,
    PIPE_COLOR,
    SOCK_COLOR,
    EXEC_COLOR,
    BOOKMARK_COLOR,
    TRASH_COLOR
};

void 
parse_colours(		void);

gint 
set_treeview_colours(	GtkTreeView * treeview);

gboolean
set_row_colours(	GtkTreeModel * treemodel, 
		        GtkTreeIter * iter, 
			GtkTreeRowReference *reference,
			gint colour_code);

gboolean 
switch_colors(		GtkTreeModel * treemodel, 
			GtkTreePath * treepath, 
			GtkTreeIter * iter, 
			gpointer data);

#endif
